==> pointpos_api-0.0.16.tar.gz: test/item_category_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for ItemCategoryApi
void main() {
  var instance = new ItemCategoryApi();

  group('tests for ItemCategoryApi', () {
    // Create Itemcategory
    //
    // Create Itemcategory
    //
    //Future<ItemCategory> createItemcategory(String authorization, String xAPIKey, ItemCategory body, { String xPin }) async 
    test('test createItemcategory', () async {
      // TODO
    });

    // Delete Itemcategory By ID
    //
    // Delete Itemcategory By ID
    //
    //Future deleteItemcategoryByID(String authorization, String xAPIKey, num id, { String xPin }) async 
    test('test deleteItemcategoryByID', () async {
      // TODO
    });

    // Get Itemcategory List
    //
    // Get Itemcategory  List
    //
    //Future<List<ItemCategory>> findItemcategory(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter }) async 
    test('test findItemcategory', () async {
      // TODO
    });

    // Get Itemcategory By ID
    //
    // Get Itemcategory By ID
    //
    //Future<ItemCategory> getItemcategoryByID(String authorization, String xAPIKey, num id, { String xPin }) async 
    test('test getItemcategoryByID', () async {
      // TODO
    });

    // Update Itemcategory By ID
    //
    // Update [object Object] By ID
    //
    //Future<ItemCategory> updateItemcategoryByID(String authorization, String xAPIKey, num id, ItemCategory body, { String xPin }) async 
    test('test updateItemcategoryByID', () async {
      // TODO
    });

  });
}

==> pointpos_api-0.2.1.tar.gz: test/item_category_api_test.dart <==
import 'package:pointpos_api/api.dart';
import 'package:test/test.dart';


/// tests for ItemCategoryApi
void main() {
  var instance = new ItemCategoryApi();

  group('tests for ItemCategoryApi', () {
    // Create Itemcategory
    //
    // Create Itemcategory
    //
    //Future<ItemCategory> createItemcategory(String authorization, String xAPIKey, ItemCategory body, { String xPin }) async 
    test('test createItemcategory', () async {
      // TODO
    });

    // Delete Itemcategory By ID
    //
    // Delete Itemcategory By ID
    //
    //Future deleteItemcategoryByID(String authorization, String xAPIKey, num id, { String xPin }) async 
    test('test deleteItemcategoryByID', () async {
      // TODO
    });

    // Get Itemcategory List
    //
    // Get Itemcategory  List
    //
    //Future<List<ItemCategory>> findItemcategory(String authorization, String xAPIKey, { String xPin, num limit, num offset, String sort, String direction, List<String> filter, bool withDeleted }) async 
    test('test findItemcategory', () async {
      // TODO
    });

    // Get Itemcategory By ID
    //
    // Get Itemcategory By ID
    //
    //Future<ItemCategory> getItemcategoryByID(String authorization, String xAPIKey, num id, { String xPin }) async 
    test('test getItemcategoryByID', () async {
      // TODO
    });

    // Update Itemcategory By ID
    //
    // Update [object Object] By ID
    //
    //Future<ItemCategory> updateItemcategoryByID(String authorization, String xAPIKey, num id, ItemCategory body, { String xPin }) async 
    test('test updateItemcategoryByID', () async {
      // TODO
    });

  });
}
